@@ -15,6 +15,8 @@
 Test class for DRAC inspection interface
 """
 
+from xml.etree import ElementTree
+
 from dracclient import exceptions as drac_exceptions
 import mock
 
@@ -125,6 +127,7 @@ class DracInspectionTestCase(db_base.DbTestCase):
              'speed': '1000 Mbps',
              'duplex': 'full duplex',
              'media_type': 'Base T'}]
+
         bios_boot_settings = {'BootMode': {'current_value': 'Bios'}}
         uefi_boot_settings = {'BootMode': {'current_value': 'Uefi'},
                               'PxeDev1EnDis': {'current_value': 'Enabled'},
@@ -136,9 +139,8 @@ class DracInspectionTestCase(db_base.DbTestCase):
                               'PxeDev2Interface': None,
                               'PxeDev3Interface': None,
                               'PxeDev4Interface': None}
-        nic_settings = {'LegacyBootProto': {'current_value': 'PXE'},
-                        'FQDD': 'NIC.Embedded.1-1-1'}
-
+        self.nic_settings = {'LegacyBootProto': 'PXE',
+                             'FQDD': 'NIC.Embedded.1-1-1'}
         self.memory = [test_utils.dict_to_namedtuple(values=m) for m in memory]
         self.cpus = [test_utils.dict_to_namedtuple(values=c) for c in cpus]
         self.virtual_disks = [test_utils.dict_to_namedtuple(values=vd)
@@ -148,29 +150,34 @@ class DracInspectionTestCase(db_base.DbTestCase):
         self.nics = [test_utils.dict_to_namedtuple(values=n) for n in nics]
         self.bios_boot_settings = test_utils.dict_of_object(bios_boot_settings)
         self.uefi_boot_settings = test_utils.dict_of_object(uefi_boot_settings)
-        self.nic_settings = test_utils.dict_of_object(nic_settings)
 
     def test_get_properties(self):
         expected = drac_common.COMMON_PROPERTIES
         driver = drac_inspect.DracInspect()
         self.assertEqual(expected, driver.get_properties())
 
+    @mock.patch.object(drac_inspect.DracInspect, '_list_nic_settings',
+                       spec_set=True, autospec=True)
     @mock.patch.object(drac_common, 'get_drac_client', spec_set=True,
                        autospec=True)
     @mock.patch.object(objects.Port, 'create', spec_set=True, autospec=True)
-    def test_inspect_hardware(self, mock_port_create, mock_get_drac_client):
+    def test_inspect_hardware(self,
+                              mock_port_create,
+                              mock_get_drac_client,
+                              mock__list_nic_settings):
         expected_node_properties = {
             'memory_mb': 32768,
             'local_gb': 1116,
             'cpus': 18,
             'cpu_arch': 'x86_64'}
         mock_client = mock.Mock()
+        mock__list_nic_settings.return_value = self.nic_settings
         mock_get_drac_client.return_value = mock_client
         mock_client.list_memory.return_value = self.memory
         mock_client.list_cpus.return_value = self.cpus
         mock_client.list_virtual_disks.return_value = self.virtual_disks
         mock_client.list_nics.return_value = self.nics
-        mock_client.list_bios_settings.return_value = self.uefi_boot_settings
+        mock_client.list_bios_settings.return_value = self.bios_boot_settings
 
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
@@ -198,24 +205,28 @@ class DracInspectionTestCase(db_base.DbTestCase):
             self.assertRaises(exception.HardwareInspectionFailure,
                               task.driver.inspect.inspect_hardware, task)
 
+    @mock.patch.object(drac_inspect.DracInspect, '_list_nic_settings',
+                       spec_set=True, autospec=True)
     @mock.patch.object(drac_common, 'get_drac_client', spec_set=True,
                        autospec=True)
     @mock.patch.object(objects.Port, 'create', spec_set=True, autospec=True)
     def test_inspect_hardware_no_virtual_disk(self, mock_port_create,
-                                              mock_get_drac_client):
+                                              mock_get_drac_client,
+                                              mock__list_nic_settings):
         expected_node_properties = {
             'memory_mb': 32768,
             'local_gb': 279,
             'cpus': 18,
             'cpu_arch': 'x86_64'}
         mock_client = mock.Mock()
+        mock__list_nic_settings.return_value = self.nic_settings
         mock_get_drac_client.return_value = mock_client
         mock_client.list_memory.return_value = self.memory
         mock_client.list_cpus.return_value = self.cpus
         mock_client.list_virtual_disks.return_value = []
         mock_client.list_physical_disks.return_value = self.physical_disks
         mock_client.list_nics.return_value = self.nics
-        mock_client.list_bios_settings.return_value = self.uefi_boot_settings
+        mock_client.list_bios_settings.return_value = self.bios_boot_settings
 
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
@@ -244,24 +255,27 @@ class DracInspectionTestCase(db_base.DbTestCase):
             self.assertRaises(exception.HardwareInspectionFailure,
                               task.driver.inspect.inspect_hardware, task)
 
+    @mock.patch.object(drac_inspect.DracInspect, '_list_nic_settings',
+                       spec_set=True, autospec=True)
     @mock.patch.object(drac_common, 'get_drac_client', spec_set=True,
                        autospec=True)
     @mock.patch.object(objects.Port, 'create', spec_set=True, autospec=True)
     def test_inspect_hardware_with_existing_ports(self, mock_port_create,
-                                                  mock_get_drac_client):
+                                                  mock_get_drac_client,
+                                                  mock__list_nic_settings):
         expected_node_properties = {
             'memory_mb': 32768,
             'local_gb': 1116,
             'cpus': 18,
             'cpu_arch': 'x86_64'}
         mock_client = mock.Mock()
+        mock__list_nic_settings.return_value = self.nic_settings
         mock_get_drac_client.return_value = mock_client
         mock_client.list_memory.return_value = self.memory
         mock_client.list_cpus.return_value = self.cpus
         mock_client.list_virtual_disks.return_value = self.virtual_disks
         mock_client.list_nics.return_value = self.nics
-        mock_client.list_bios_settings.return_value = self.uefi_boot_settings
-
+        mock_client.list_bios_settings.return_value = self.bios_boot_settings
         mock_port_create.side_effect = exception.MACAlreadyExists("boom")
 
         with task_manager.acquire(self.context, self.node.uuid,
@@ -312,14 +326,18 @@ class DracInspectionTestCase(db_base.DbTestCase):
 
             self.assertEqual(expected_pxe_nic, pxe_dev_nics[0])
 
+    @mock.patch.object(drac_inspect.DracInspect, '_list_nic_settings',
+                       spec_set=True, autospec=True)
     @mock.patch.object(drac_common, 'get_drac_client', spec_set=True,
                        autospec=True)
-    def test__get_pxe_dev_nics_with_BIOS_boot_mode(self, mock_get_drac_client):
+    def test__get_pxe_dev_nics_with_BIOS_boot_mode(self,
+                                                   mock_get_drac_client,
+                                                   mock__list_nic_settings):
         expected_pxe_nic = self.nic_settings['FQDD']
         mock_client = mock.Mock()
         mock_get_drac_client.return_value = mock_client
+        mock__list_nic_settings.return_value = self.nic_settings
         mock_client.list_bios_settings.return_value = self.bios_boot_settings
-        mock_client.list_nic_settings.return_value = self.nic_settings
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
             pxe_dev_nics = task.driver.inspect._get_pxe_dev_nics(
@@ -327,15 +345,17 @@ class DracInspectionTestCase(db_base.DbTestCase):
 
             self.assertEqual(expected_pxe_nic, pxe_dev_nics[0])
 
+    @mock.patch.object(drac_inspect.DracInspect, '_list_nic_settings',
+                       spec_set=True, autospec=True)
     @mock.patch.object(drac_common, 'get_drac_client', spec_set=True,
                        autospec=True)
-    def test__get_pxe_dev_nics_list_boot_setting_failure(self,
-                                                         mock_get_drac_client):
+    def test__get_pxe_dev_nics_list_boot_setting_failure(
+            self, mock_get_drac_client, mock__list_nic_settings):
         mock_client = mock.Mock()
         mock_get_drac_client.return_value = mock_client
         mock_client.list_bios_settings.side_effect = (
             drac_exceptions.BaseClientException('foo'))
-
+        mock__list_nic_settings.return_value = self.nic_settings
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
             self.assertRaises(exception.HardwareInspectionFailure,
@@ -344,14 +364,16 @@ class DracInspectionTestCase(db_base.DbTestCase):
                               self.nics,
                               self.node)
 
+    @mock.patch.object(drac_inspect.DracInspect, '_list_nic_settings',
+                       spec_set=True, autospec=True)
     @mock.patch.object(drac_common, 'get_drac_client', spec_set=True,
                        autospec=True)
-    def test__get_pxe_dev_nics_list_nic_setting_failure(self,
-                                                        mock_get_drac_client):
+    def test__get_pxe_dev_nics_list_nic_setting_failure(
+            self, mock_get_drac_client, mock__list_nic_settings):
         mock_client = mock.Mock()
         mock_get_drac_client.return_value = mock_client
         mock_client.list_bios_settings.return_value = self.bios_boot_settings
-        mock_client.list_nic_settings.side_effect = (
+        mock__list_nic_settings.side_effect = (
             drac_exceptions.BaseClientException('bar'))
 
         with task_manager.acquire(self.context, self.node.uuid,
@@ -362,18 +384,43 @@ class DracInspectionTestCase(db_base.DbTestCase):
                               self.nics,
                               self.node)
 
+    @mock.patch.object(drac_inspect.DracInspect, '_list_nic_settings',
+                       spec_set=True, autospec=True)
     @mock.patch.object(drac_common, 'get_drac_client', spec_set=True,
                        autospec=True)
-    def test__get_pxe_dev_nics_with_empty_list(self, mock_get_drac_client):
+    def test__get_pxe_dev_nics_with_empty_list(self,
+                                               mock_get_drac_client,
+                                               mock__list_nic_settings):
         expected_pxe_nic = []
         nic_setting = []
         mock_client = mock.Mock()
         mock_get_drac_client.return_value = mock_client
+        mock__list_nic_settings.return_value = nic_setting
         mock_client.list_bios_settings.return_value = self.bios_boot_settings
-        mock_client.list_nic_settings.return_value = nic_setting
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=True) as task:
             pxe_dev_nics = task.driver.inspect._get_pxe_dev_nics(
                 mock_client, self.nics, self.node)
 
             self.assertEqual(expected_pxe_nic, pxe_dev_nics)
+
+    @mock.patch.object(drac_inspect.DracInspect, '_list_nic_settings',
+                       spec_set=True, autospec=True)
+    @mock.patch.object(drac_common, 'get_drac_client', spec_set=True,
+                       autospec=True)
+    def test__list_nic_settings(self,
+                                mock_get_drac_client,
+                                mock__list_nic_settings):
+        pxe_nic = self.nic_settings['FQDD']
+        nic_setting = {}
+        mock_client = mock.Mock()
+        mock_get_drac_client.return_value = mock_client
+        mock__list_nic_settings.return_value = self.nic_settings
+        mock_client.invoke.return_value = ElementTree.fromstring(
+            test_utils.NICEnumerations[drac_inspect.DCIM_NICEnumeration]['ok'])
+        with task_manager.acquire(self.context,
+                                  self.node.uuid,
+                                  shared=True) as task:
+            nic_setting = task.driver.inspect._list_nic_settings(mock_client,
+                                                                 pxe_nic)
+            self.assertEqual(self.nic_settings, nic_setting)
