@@ -12,13 +12,20 @@
 #    under the License.
 
 import collections
+import os
 
 
-class DictToObj(object):
-    """Returns a dictionary into a class"""
-    def __init__(self, dictionary):
-        for key in dictionary:
-            setattr(self, key, dictionary[key])
+DCIM_NICEnumeration = ('http://schemas.dell.com/wbem/wscim/1/cim-schema/2/'
+                       'DCIM_NICEnumeration')  # noqa
+
+FAKE_ENDPOINT = {
+    'host': '1.2.3.4',
+    'port': '443',
+    'path': '/wsman',
+    'protocol': 'https',
+    'username': 'admin',
+    'password': 's3cr3t'
+}
 
 
 def dict_to_namedtuple(name='GenericNamedTuple', values=None):
@@ -30,6 +37,13 @@ def dict_to_namedtuple(name='GenericNamedTuple', values=None):
     return collections.namedtuple(name, list(values))(**values)
 
 
+class DictToObj(object):
+    """Returns a dictionary into a class"""
+    def __init__(self, dictionary):
+        for key in dictionary:
+            setattr(self, key, dictionary[key])
+
+
 def dict_of_object(data):
     """Create a dictionary object"""
 
@@ -38,3 +52,20 @@ def dict_of_object(data):
             dict_obj = DictToObj(v)
             data[k] = dict_obj
     return data
+
+
+def load_wsman_xml(name):
+    """Helper function to load a WSMan XML response from a file."""
+
+    with open(os.path.join(os.path.dirname(__file__), 'wsman_mocks',
+                           '%s.xml' % name), 'r') as f:
+        xml_body = f.read()
+
+    return xml_body
+
+
+NICEnumerations = {
+    DCIM_NICEnumeration: {
+        'ok': load_wsman_xml('nic_enumeration-enum-ok'),
+    }
+}
